//
// Created by danii on 07.10.2022.
//
#include <bits/stdc++.h>

using namespace std;

#define eps 1e-9

struct Vector;

struct Point {
    double x, y;

    Point() {
        x = y = 0;
    }

    Point(double xx, double yy) {
        x = xx;
        y = yy;
    }

    Point operator*(const double a) const {
        return {x * a, y * a};
    }

    Point operator-(const Point &other) const {
        return {x - other.x, y - other.y};
    }

    Point operator+(const Point &other) const {
        return {x + other.x, y + other.y};
    }

    ostream &operator<<(ostream &out) const {
        out << x << ' ' << y << '\n';
        return out;
    }
};

istream &operator>>(istream &in, Point &a) {
    in >> a.x >> a.y;
    return in;
}

ostream &operator<<(ostream &out, Point &a) {
    out << a.x << ' ' << a.y;
    return out;
}

struct Vector {
    double x, y;

    Vector() {
        x = y = 0;
    }

    Vector(Point a, Point b) {
        x = a.x - b.x;
        y = a.y - b.y;
    }

    explicit Vector(Point a) {
        x = a.x;
        y = a.y;
    }

    Vector operator*(const double a) const {
        return Vector(Point(x * a, y * a));
    }

    [[nodiscard]] Vector normalize() const {
        return *this * (1 / sz());
    }

    Vector operator+(const Vector &other) const {
        return Vector(Point(x + other.x, y + other.y));
    }

    Vector operator-(const Vector &other) const {
        return Vector(Point(x - other.x, y - other.y));
    }

    [[nodiscard]] double sz() const {
        return sqrt(x * x + y * y);
    }
};

ostream &operator<<(ostream &out, Vector &a) {
    cout << a.x << ' ' << a.y;
    return out;
}

double dot_product(Vector a, Vector b) {
    return a.x * b.x + a.y * b.y;
}

double vector_product(Vector a, Vector b) {
    return a.x * b.y - a.y * b.x;
}

double count_angle(Vector a, Vector b) {
    return acos(dot_product(a, b) / (a.sz() * b.sz())) * 180 / 3.14159265358979323846;
}

bool operator==(const Point &a, const Point &b) {
    return fabs(a.x - b.x) < eps && fabs(a.y - b.y) < eps;
}

bool operator==(const Vector &a, const Vector &b) {
    return fabs(a.x - b.x) < eps && fabs(a.y - b.y) < eps;
}

bool operator>(const Point &a, const Point &b) {
    return a.x > b.x || (a.x == b.x && a.y > b.y);
}

bool operator<(const Point &a, const Point &b) {
    return a.x < b.x || (a.x == b.x && a.y < b.y);
}

Point &min(Point &a, Point &b) {
    if (a > b)
        return b;
    return a;
}

Point &max(Point &a, Point &b) {
    if (a < b)
        return b;
    return a;
}

int main() {
    long long d, h, w, k;

    cin >> d >> h >> w >> k;

    Vector shot_on_top = Vector(Point(0, 0), Point(d, w)).normalize() * k;

    if (w * 2 <= h && sqrt(d * d + w * w) * 2 <= k) {
        cout << count_angle(shot_on_top, Vector(Point(0, 0), Point(1, 0))) << '\n';
    } else if (k >= 2 * d && sqrt(k * k - 4 * d * d) / 2 >= w) {
        cout << count_angle(Vector(Point(0, 0), Point(2 * d, sqrt(k * k - 4 * d * d))),
                                   Vector(Point(0, 0), Point(1, 0))) << '\n';
    } else {
        cout << -1 << '\n';
    }
    return 0;
}

