//  Copyright 2022 Nikita Golikov

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
    #define debug(x) cerr << (#x) << ":\t" << (x) << endl
#else
    #define debug(x) 238;
#endif

template <class A, class B>
bool smin(A &x, B &&y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A &x, B &&y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

//  by https://codeforces.com/profile/Nyaan
//  example submission:
//  https://codeforces.com/contest/1603/submission/133688639
template <uint32_t mod>
struct LazyMontgomeryModInt {
  using mint = LazyMontgomeryModInt;
  using i32 = int32_t;
  using u32 = uint32_t;
  using u64 = uint64_t;
 
  static constexpr u32 get_r() {
    u32 ret = mod;
    for (i32 i = 0; i < 4; ++i) ret *= 2 - mod * ret;
    return ret;
  }
 
  static constexpr u32 r = get_r();
  static constexpr u32 n2 = -u64(mod) % mod;
  static_assert(r * mod == 1, "invalid, r * mod != 1");
  static_assert(mod < (1 << 30), "invalid, mod >= 2 ^ 30");
  static_assert((mod & 1) == 1, "invalid, mod % 2 == 0");
 
  u32 a;
 
  constexpr LazyMontgomeryModInt() : a(0) {}
  constexpr LazyMontgomeryModInt(const int64_t &b)
      : a(reduce(u64(b % mod + mod) * n2)){};
 
  static constexpr u32 reduce(const u64 &b) {
    return (b + u64(u32(b) * u32(-r)) * mod) >> 32;
  }
 
  constexpr mint &operator+=(const mint &b) {
    if (i32(a += b.a - 2 * mod) < 0) a += 2 * mod;
    return *this;
  }

  constexpr mint &operator++() {
    return *this += 1;
  }

  constexpr mint operator++(int) {
    auto ret = *this;
    *this += 1;
    return ret;
  }

  constexpr mint &operator-=(const mint &b) {
    if (i32(a -= b.a) < 0) a += 2 * mod;
    return *this;
  }

  constexpr mint &operator--() {
    return *this -= 1;
  }

  constexpr mint operator--(int) {
    auto ret = *this;
    *this -= 1;
    return ret;
  }
 
  constexpr mint &operator*=(const mint &b) {
    a = reduce(u64(a) * b.a);
    return *this;
  }
 
  constexpr mint &operator/=(const mint &b) {
    *this *= b.inv();
    return *this;
  }
 
  constexpr friend mint operator+(mint a, const mint &b) { return a += b; }
  constexpr friend mint operator-(mint a, const mint &b) { return a -= b; }
  constexpr friend mint operator*(mint a, const mint &b) { return a *= b; }
  constexpr friend mint operator/(mint a, const mint &b) { return a /= b; }
  constexpr friend bool operator==(mint const& a, const mint &b) {
    return (a.a >= mod ? a.a - mod : a.a) == (b.a >= mod ? b.a - mod : b.a);
  }
  constexpr friend bool operator!=(mint const& a, const mint &b) {
    return (a.a >= mod ? a.a - mod : a.a) != (b.a >= mod ? b.a - mod : b.a);
  }
  constexpr friend bool operator<(mint const& a, const mint &b) {
    return (a.a >= mod ? a.a - mod : a.a) < (b.a >= mod ? b.a - mod : b.a);
  }
  constexpr mint operator-() const { return mint() - mint(*this); }
 
  constexpr mint power(u64 n) const {
    mint ret(1), mul(*this);
    while (n > 0) {
      if (n & 1) ret *= mul;
      mul *= mul;
      n >>= 1;
    }
    return ret;
  }
  
  constexpr mint inv() const { return power(mod - 2); }
 
  friend ostream &operator<<(ostream &os, const mint &b) {
    return os << b.get();
  }
 
  friend istream &operator>>(istream &is, mint &b) {
    int64_t t;
    is >> t;
    b = LazyMontgomeryModInt<mod>(t);
    return (is);
  }
  
  constexpr u32 get() const {
    u32 ret = reduce(a);
    return ret >= mod ? ret - mod : ret;
  }

  constexpr explicit operator bool() const {
    return bool(get());
  }
 
  static constexpr u32 get_mod() { return mod; }
};
 
template <typename T>
struct Binomial {
  vector<T> f, g, h;
  Binomial(int MAX = 0) : f(1, T(1)), g(1, T(1)), h(1, T(1)) {
    extend(MAX + 1);    
  }

  void extend(int m) {
    int n = f.size();

    if (n >= m) {
      return;
    }

    f.resize(m);
    g.resize(m);
    h.resize(m);
    for (int i = n; i < m; i++) f[i] = f[i - 1] * T(i);
    g[m - 1] = f[m - 1].inv();
    h[m - 1] = g[m - 1] * f[m - 2];
    for (int i = m - 2; i >= n; i--) {
      g[i] = g[i + 1] * T(i + 1);
      h[i] = g[i] * f[i - 1];
    } 
  }

  void extend() {
    extend(2 * f.size());
  }
 
  T fact(int i) {
    if (i < 0) return T(0);
    while (i >= (int)f.size()) extend();
    return f[i];
  }
 
  T ifact(int i) {
    if (i < 0) return T(0);
    while (i >= (int)g.size()) extend();
    return g[i];
  }
 
  T inv(int i) {
    if (i < 0) return -inv(-i);
    while (i >= (int)h.size()) extend();
    return h[i];
  }
 
  T C(int n, int r) {
    if (n < 0 || n < r || r < 0) return T(0);
    return fact(n) * ifact(n - r) * ifact(r);
  }
 
  inline T operator()(int n, int r) { return C(n, r); }
 
  template <typename I>
  T multinomial(const vector<I>& r) {
    static_assert(is_integral<I>::value == true);
    int n = 0;
    for (auto& x : r) {
      if(x < 0) return T(0);
      n += x;
    }
    T res = fact(n);
    for (auto& x : r) res *= ifact(x);
    return res;
  }
 
  template <typename I>
  T operator()(const vector<I>& r) {
    return multinomial(r);
  }
 
  T C_naive(int n, int r) {
    if (n < 0 || n < r || r < 0) return T(0);
    T ret = T(1);
    r = min(r, n - r);
    for (int i = 1; i <= r; ++i) ret *= inv(i) * (n--);
    return ret;
  }
 
  T A(int n, int r) {
    if (n < 0 || n < r || r < 0) return T(0);
    return fact(n) * ifact(n - r);
  }
 
  T CR(int n, int r) {
    if (n < 0 || r < 0) return T(0);
    return r == 0 ? 1 : C(n + r - 1, r);
  }
};
int const MOD = 998244353;
// int const MOD = int(1e9 + 7);
using mint = LazyMontgomeryModInt<MOD>;
Binomial<mint> C;

vector<mint> mkpow(mint base, int mx) {
  vector<mint> res(mx + 1);
  res[0] = 1;
  for (int i = 1; i <= mx; ++i) {
    res[i] = res[i - 1] * base;
  }
  return res;
}

// #define FAST_RANDOM

#ifndef FAST_RANDOM
#ifdef GOLIKOV
mt19937_64 rng(566);
#else
mt19937_64 rng(chrono::steady_clock::now().time_since_epoch().count());
#endif

template <typename T>
T rnd_helper(T from, T to, true_type) {
  return uniform_int_distribution<T>(from, to)(rng);
}

template <typename T>
T rnd_helper(T from, T to, false_type) {
  return uniform_real_distribution<T>(from, to)(rng);
}

template <typename T>
T rnd(T from, T to) {
  return rnd_helper(from, to, is_integral<T>{});
}
#else
  using ui32 = uint32_t;
  ui32 SEED = 471241271;

  ui32 xorshift32() {
    SEED ^= SEED << 13u;
    SEED ^= SEED >> 17u;
    SEED ^= SEED << 5u;
    return SEED;
  }

  template <class T>
  T rnd_helper(T from, T to, false_type) {
    return from + (to - from) * (T(1) * xorshift32() / numeric_limits<ui32>::max());
  }

  template <class T>
  T rnd_helper(T from, T to, true_type) {
    return from + xorshift32() % (to - from + 1);
  }

  template <class T>
  T rnd(T from, T to) {
    return rnd_helper(from, to, is_integral<T>{});
  }
#endif

struct Hashes {
  static int const MOD1 = int(1e9 + 403);
  static int const MOD2 = int(1e9 + 787);
  using m1 = LazyMontgomeryModInt<MOD1>;
  using m2 = LazyMontgomeryModInt<MOD2>;

  struct hash_t {
    m1 x;
    m2 y;

    hash_t(int v = 0) : x(v), y(v) {}
    hash_t(m1 x_, m2 y_) : x(x_), y(y_) {}

    hash_t operator+(hash_t const& other) const {
      return hash_t{x + other.x, y + other.y};
    }

    hash_t& operator+=(hash_t const& other) {
      x += other.x; y += other.y; return *this;
    }

    hash_t operator*(hash_t const& other) const {
      return hash_t{x * other.x, y * other.y};
    }

    hash_t operator-(hash_t const& other) const {
      return hash_t{x - other.x, y - other.y};
    }

    bool operator==(hash_t const& other) const {
      return x == other.x && y == other.y;
    }

    bool operator!=(hash_t const& other) const {
      return x != other.x || y != other.y;
    }
  };
  vector<hash_t> powers, ipowers;
  hash_t BASE, IBASE;

  Hashes(int n) {
    BASE.x = rnd(1000, MOD1 - 1000);
    BASE.y = rnd(1000, MOD2 - 1000);
    IBASE.x = BASE.x.inv();
    IBASE.y = BASE.y.inv();
    powers.resize(n + 1);
    ipowers.resize(n + 1);
    powers[0] = 1;
    ipowers[0] = 1;
    for (int i = 1; i <= n; ++i) {
      powers[i] = powers[i - 1] * BASE;
      ipowers[i] = ipowers[i - 1] * IBASE;
    }
  }
};

array<int, 26> INIT{};

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  string s; cin >> s;

  int n = int(s.size());
  Hashes hashes(n);
  using ht = Hashes::hash_t; 
  for (int i = 0; i < 26; ++i) {
    INIT[i] = i;
  }
  struct node {
    array<ht, 26> sum{};
    array<int, 26> mod = INIT;

    node operator+(node const& other) const {
      node res{};
      for (int i = 0; i < 26; ++i) {
        res.sum[i] = sum[i] + other.sum[i];
      }
      return res;
    }

    void apply(array<int, 26> f) {
      array<ht, 26> newSum{};
      array<int, 26> newMod{};
      for (int i = 0; i < 26; ++i) {
        newSum[f[i]] += sum[i];
        newMod[i] = f[mod[i]];
      }
      sum = newSum;
      mod = newMod;
    }
  };
  int pw = 1;
  while (pw < n) pw *= 2;
  vector<node> tree(2 * pw);
  for (int i = 0; i < n; ++i) {
    tree[pw + i].sum[s[i] - 'a'] = hashes.powers[i];
  }
  for (int i = pw - 1; i > 0; --i) {
    tree[i] = tree[2 * i] + tree[2 * i + 1];
  }

  auto push = [&](int v) {
    if (tree[v].mod != INIT) {
      tree[2 * v].apply(tree[v].mod);
      tree[2 * v + 1].apply(tree[v].mod);
      tree[v].mod = INIT;
    }
  };
  auto Get = [&](int ql, int qr) {
    auto rec = [&](auto&& self, int v, int l, int r) -> node {
      if (l >= qr || ql >= r) return node();
      if (ql <= l && r <= qr) {
        return tree[v];
      }
      int m = (l + r) / 2;
      push(v);
      return self(self, 2 * v, l, m) + self(self, 2 * v + 1, m, r);
    };
    auto res = rec(rec, 1, 0, pw);
    ht ans{};
    for (int i = 0; i < 26; ++i) {
      ans += ht(i + 1) * res.sum[i];
    }
    return ans;
  };
  auto Set = [&](int pos, int ch) {
    auto rec = [&](auto&& self, int v, int l, int r) -> void {
      if (l + 1 == r) {
        tree[v].sum.fill(ht());
        tree[v].sum[ch] = hashes.powers[pos];
        return;
      }
      int m = (l + r) / 2;
      push(v);
      if (pos < m) {
        self(self, 2 * v, l, m);
      } else {
        self(self, 2 * v + 1, m, r);
      }
      tree[v] = tree[2 * v] + tree[2 * v + 1];
    };
    rec(rec, 1, 0, pw);
  };

  int q; cin >> q;
  while (q--) {
    int tp; cin >> tp;
    if (tp == 1) {
      int pos;
      char ch;
      cin >> pos >> ch;
      --pos;
      Set(pos, ch - 'a');
    } else if (tp == 2) {
      char x, y;
      cin >> x >> y;
      auto mod = INIT;
      mod[x - 'a'] = y - 'a';
      tree[1].apply(mod);
    } else {
      int l1, r1, l2, r2;
      cin >> l1 >> r1 >> l2 >> r2;
      --l1, --l2;
      if (r1 - l1 != r2 - l2) {
        cout << "NO\n";
      } else {
        auto h1 = Get(l1, r1);
        auto h2 = Get(l2, r2);
        if (l1 <= l2) {
          h1 = h1 * hashes.powers[l2 - l1];
        } else {
          h2 = h2 * hashes.powers[l1 - l2];
        }
        if (h1 == h2) {
          cout << "YES\n";
        } else {
          cout << "NO\n";
        }
      }
    }
  }

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
